pub struct KnowledgeSurfaceBinding { /* private fields */ }Expand description
Immutable multi-instance Knowledge readiness value accepted by the Code capability projection kernel.
Projection digests are opaque host evidence. Code canonicalizes and binds them but does not interpret scopes, open package files, query an index, or select a cognitive package.
Implementations
Sourceimpl KnowledgeSurfaceBinding
impl KnowledgeSurfaceBinding
pub fn new( spec: KnowledgeSurfaceBindingSpec, ) -> Result<Self, KnowledgeSurfaceBindingError>
pub fn public_name(&self) -> &str
pub fn format_version(&self) -> &str
pub fn content_digest(&self) -> &Sha256Digest
pub fn projection_digests(&self) -> &[Sha256Digest]
pub fn surface_digest(&self) -> &Sha256Digest