pub struct RunCapabilityBindingV1 { /* private fields */ }Expand description
Serializable identity of the complete immutable capability generation and authority ceiling admitted for one Agent Run.
Runtime values, package paths, credentials, and leases are intentionally absent. A recovery host reconstructs those values, then Code verifies this identity before the target Run is created.
Implementations
Sourceimpl RunCapabilityBindingV1
impl RunCapabilityBindingV1
pub fn from_set_and_ceiling( set: &CapabilitySet, ceiling: &CapabilityCeiling, ) -> Result<Self, RunCapabilityBindingError>
pub fn validate(&self) -> Result<(), RunCapabilityBindingError>
pub fn ensure_matches( &self, set: &CapabilitySet, ceiling: &CapabilityCeiling, ) -> Result<(), RunCapabilityBindingError>
pub fn schema(&self) -> &str
pub fn capability_set_schema(&self) -> &str
pub const fn code_catalog_generation(&self) -> u64
pub fn catalog_digest(&self) -> &str
pub fn capability_ceiling_schema(&self) -> &str
pub fn capability_ceiling_digest(&self) -> &str
pub fn use_generation(&self) -> Option<&RunUseCapabilityGenerationV1>