pub struct LanguageId(/* private fields */);Expand description
Extensible identifier for a programming language.
Values use the language identifier understood by the active semantic runtime. This is a newtype rather than an enum so adding language support does not require changing the public contract.
Implementations