pub struct ProviderConfig {
pub name: String,
pub api_key: Option<String>,
pub base_url: Option<String>,
pub headers: HashMap<String, String>,
pub session_id_header: Option<String>,
pub models: Vec<ModelConfig>,
}Expand description
Provider configuration
Fields
name: StringProvider name (e.g., “anthropic”, “openai”)
api_key: Option<String>API key for this provider
base_url: Option<String>Base URL for the API
headers: HashMap<String, String>Static HTTP headers for this provider
session_id_header: Option<String>Header name to receive the runtime session ID
models: Vec<ModelConfig>Available models
Implementations
Sourceimpl ProviderConfig
impl ProviderConfig
Sourcepub fn find_model(&self, model_id: &str) -> Option<&ModelConfig>
pub fn find_model(&self, model_id: &str) -> Option<&ModelConfig>
Find a model by ID
Sourcepub fn get_api_key<'a>(&'a self, model: &'a ModelConfig) -> Option<&'a str>
pub fn get_api_key<'a>(&'a self, model: &'a ModelConfig) -> Option<&'a str>
Get the effective API key for a model (model override or provider default)
Sourcepub fn get_base_url<'a>(&'a self, model: &'a ModelConfig) -> Option<&'a str>
pub fn get_base_url<'a>(&'a self, model: &'a ModelConfig) -> Option<&'a str>
Get the effective base URL for a model (model override or provider default)
Sourcepub fn get_headers(&self, model: &ModelConfig) -> HashMap<String, String>
pub fn get_headers(&self, model: &ModelConfig) -> HashMap<String, String>
Get the effective static headers for a model (provider defaults with model overrides)
Sourcepub fn get_session_id_header<'a>(
&'a self,
model: &'a ModelConfig,
) -> Option<&'a str>
pub fn get_session_id_header<'a>( &'a self, model: &'a ModelConfig, ) -> Option<&'a str>
Get the header name that should carry the runtime session ID.