pub struct ContextSourcePolicy {
pub max_items_per_source: Option<usize>,
pub max_tokens_per_source: Option<usize>,
}Expand description
Source-aware limits that prevent one context source from dominating the prompt.
Fields
max_items_per_source: Option<usize>max_tokens_per_source: Option<usize>Trait Implementations
Sourceimpl Clone for ContextSourcePolicy
impl Clone for ContextSourcePolicy
Sourcefn clone(&self) -> ContextSourcePolicy
fn clone(&self) -> ContextSourcePolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContextSourcePolicy
impl Debug for ContextSourcePolicy
Sourceimpl Default for ContextSourcePolicy
impl Default for ContextSourcePolicy
Sourceimpl PartialEq for ContextSourcePolicy
impl PartialEq for ContextSourcePolicy
Sourcefn eq(&self, other: &ContextSourcePolicy) -> bool
fn eq(&self, other: &ContextSourcePolicy) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ContextSourcePolicy
impl Eq for ContextSourcePolicy
impl StructuralPartialEq for ContextSourcePolicy