pub struct CoreEventIdentity {
pub schema: String,
pub identity: CoreIdentity,
pub event_type: String,
pub payload_digest: String,
pub payload_bytes: u64,
pub observed_at_ms: u64,
pub event_digest: String,
}Expand description
Canonical digest-only identity for one runtime event.
Fields
schema: Stringidentity: CoreIdentityevent_type: Stringpayload_digest: Stringpayload_bytes: u64observed_at_ms: u64event_digest: StringImplementations
Sourceimpl CoreEventIdentity
impl CoreEventIdentity
pub fn from_agent_event( identity: CoreIdentity, observed_at_ms: u64, event: &AgentEvent, ) -> Result<Self, CoreIdentityError>
Sourcepub fn from_agent_event_at(
identity: CoreIdentity,
clock: &dyn LogicalClock,
event: &AgentEvent,
) -> Result<Self, CoreIdentityError>
pub fn from_agent_event_at( identity: CoreIdentity, clock: &dyn LogicalClock, event: &AgentEvent, ) -> Result<Self, CoreIdentityError>
Adapt an event using an injected logical clock instead of reading wall time in the caller. This keeps deterministic replay and tests separate from the system clock implementation.
Sourcepub fn from_run_event(
operation_id: OperationId,
source_revision: SourceRevision,
capability_stamp: Option<CapabilityStamp>,
record: &RunEventRecord,
) -> Result<Self, CoreIdentityError>
pub fn from_run_event( operation_id: OperationId, source_revision: SourceRevision, capability_stamp: Option<CapabilityStamp>, record: &RunEventRecord, ) -> Result<Self, CoreIdentityError>
Adapt the event representation already retained by a Code run.
pub fn validate(&self) -> Result<(), CoreIdentityError>
pub fn expected_digest(&self) -> Result<String, CoreIdentityError>