pub struct SourceRevision(/* private fields */);Expand description
Monotonic source revision used to prevent derived data crossing a source snapshot boundary. Zero means that the caller has not supplied a source revision yet; it is retained for backwards-compatible adapters.
Implementations