pub struct DurableMemorySemanticRefreshReceipt { /* private fields */ }Expand description
Secret-free evidence that one exact Active snapshot was published.
Implementations
Sourceimpl DurableMemorySemanticRefreshReceipt
impl DurableMemorySemanticRefreshReceipt
Sourcepub fn checkpoint(&self) -> DurableMemorySemanticRefreshCheckpoint
pub fn checkpoint(&self) -> DurableMemorySemanticRefreshCheckpoint
Create persistable recovery evidence without the repository-local token.
pub fn profile(&self) -> &str
pub fn source_snapshot_profile(&self) -> &str
pub fn source_snapshot_digest(&self) -> &str
pub fn source_snapshot_bytes(&self) -> usize
Sourcepub fn source_change_token(&self) -> Option<&MemoryNamespaceChangeToken>
pub fn source_change_token(&self) -> Option<&MemoryNamespaceChangeToken>
Optional bounded change evidence scoped to one repository history and schedule-ownership epoch.
pub fn semantic_binding_schema(&self) -> &str
pub fn serving_generation_digest(&self) -> &str
pub fn active_node_count(&self) -> usize
pub fn mutation_consistency(&self) -> VectorMutationConsistency
Sourcepub fn index_change_token(&self) -> Option<&VectorIndexChangeToken>
pub fn index_change_token(&self) -> Option<&VectorIndexChangeToken>
Optional exact continuity evidence for one vector-index history.
pub fn index_status(&self) -> &VectorIndexStatus