pub struct DynamicWorkflowTool { /* private fields */ }Expand description
Model-visible tool that executes a dynamic workflow through A3S Flow.
Implementations
Sourceimpl DynamicWorkflowTool
impl DynamicWorkflowTool
pub fn new(registry: Arc<ToolRegistry>) -> Self
Sourcepub fn with_graph_observer(self, observer: FlowGraphObserver) -> Self
pub fn with_graph_observer(self, observer: FlowGraphObserver) -> Self
Project committed Flow events into an optional reactive state graph. A3S Flow remains the workflow execution source of truth.