pub struct ExecutionFactInputV1 {
pub frame: ExecutionFrameV1,
pub sequence: u64,
pub observed_at_ms: u64,
pub event_type: String,
pub payload_digest: String,
pub payload_bytes: u64,
pub artifact_refs: Vec<String>,
}Expand description
Input accepted by the journal. Payload bytes are counted and represented by a digest; raw model/tool content belongs in an explicitly authorized artifact store or evidence reader.
Fields
frame: ExecutionFrameV1sequence: u64observed_at_ms: u64event_type: Stringpayload_digest: Stringpayload_bytes: u64artifact_refs: Vec<String>Implementations
Sourceimpl ExecutionFactInputV1
impl ExecutionFactInputV1
pub fn from_event( frame: ExecutionFrameV1, sequence: u64, observed_at_ms: u64, event: &AgentEvent, ) -> Result<Self, JournalError>
pub fn from_run_event( frame: ExecutionFrameV1, event: &RunEventRecord, ) -> Result<Self, JournalError>