EvaluationResultSink

Trait EvaluationResultSink 

pub trait EvaluationResultSink: Send + Sync {
    // Required methods
    fn write<'life0, 'async_trait>(
        &'life0 self,
        record: EvaluationRecordV1,
    ) -> Pin<Box<dyn Future<Output = Result<EvaluationWriteOutcomeV1, EvaluationStoreError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn get<'life0, 'life1, 'async_trait>(
        &'life0 self,
        record_digest: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Option<EvaluationRecordV1>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn list_for_target<'life0, 'life1, 'async_trait>(
        &'life0 self,
        target: &'life1 ExecutionTargetV1,
    ) -> Pin<Box<dyn Future<Output = Vec<EvaluationRecordV1>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;

    // Provided methods
    fn get_checked<'life0, 'life1, 'async_trait>(
        &'life0 self,
        record_digest: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<Option<EvaluationRecordV1>, EvaluationStoreError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
    fn list_for_target_checked<'life0, 'life1, 'async_trait>(
        &'life0 self,
        target: &'life1 ExecutionTargetV1,
    ) -> Pin<Box<dyn Future<Output = Result<Vec<EvaluationRecordV1>, EvaluationStoreError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
}

Required Methods

fn write<'life0, 'async_trait>( &'life0 self, record: EvaluationRecordV1, ) -> Pin<Box<dyn Future<Output = Result<EvaluationWriteOutcomeV1, EvaluationStoreError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn get<'life0, 'life1, 'async_trait>( &'life0 self, record_digest: &'life1 str, ) -> Pin<Box<dyn Future<Output = Option<EvaluationRecordV1>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn list_for_target<'life0, 'life1, 'async_trait>( &'life0 self, target: &'life1 ExecutionTargetV1, ) -> Pin<Box<dyn Future<Output = Vec<EvaluationRecordV1>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Provided Methods

fn get_checked<'life0, 'life1, 'async_trait>( &'life0 self, record_digest: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<Option<EvaluationRecordV1>, EvaluationStoreError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Error-reporting read variant for hosts that need to distinguish a missing record from a corrupt or unavailable backing store. Legacy implementations may use the compatibility methods above; the default keeps those implementations source-compatible.

fn list_for_target_checked<'life0, 'life1, 'async_trait>( &'life0 self, target: &'life1 ExecutionTargetV1, ) -> Pin<Box<dyn Future<Output = Result<Vec<EvaluationRecordV1>, EvaluationStoreError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors