pub fn project_needs_confirmation(
policy: &PermissionPolicy,
tool_name: &str,
) -> boolExpand description
Map a permission decision onto the tool call the fold will store.
pub fn project_needs_confirmation(
policy: &PermissionPolicy,
tool_name: &str,
) -> boolMap a permission decision onto the tool call the fold will store.