pub struct FlowGraphObserver { /* private fields */ }Implementations
Sourceimpl FlowGraphObserver
impl FlowGraphObserver
pub fn new(runtime: Arc<Mutex<GraphRuntime>>) -> Self
pub fn runtime(&self) -> Arc<Mutex<GraphRuntime>> ⓘ
pub async fn last_error(&self) -> Option<String>
pub async fn health(&self) -> FlowGraphHealthSnapshot
pub async fn project( &self, envelope: FlowEventEnvelope, ) -> Result<ExternalProjectionOutcome, RuntimeError>
Sourcepub async fn catch_up(
&self,
history: Vec<FlowEventEnvelope>,
) -> Result<usize, RuntimeError>
pub async fn catch_up( &self, history: Vec<FlowEventEnvelope>, ) -> Result<usize, RuntimeError>
Replay committed Flow history in sequence order, applying only events not already represented by the restored graph cursor.