pub trait FlowDecisionLedger: Send + Sync {
// Required methods
fn claim<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
decision_id: &'life1 str,
request_hash: &'life2 str,
owner_id: &'life3 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<FlowDecisionClaimOutcome>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn renew<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
decision_id: &'life1 str,
request_hash: &'life2 str,
owner_id: &'life3 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<bool>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn complete<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
decision_id: &'life1 str,
request_hash: &'life2 str,
owner_id: &'life3 str,
completed_at_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn release<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
decision_id: &'life1 str,
request_hash: &'life2 str,
owner_id: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
// Provided method
fn prune_completed<'life0, 'async_trait>(
&'life0 self,
_before_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<usize>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
}Required Methods
fn claim<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
decision_id: &'life1 str,
request_hash: &'life2 str,
owner_id: &'life3 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<FlowDecisionClaimOutcome>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Sourcefn renew<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
decision_id: &'life1 str,
request_hash: &'life2 str,
owner_id: &'life3 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<bool>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn renew<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
decision_id: &'life1 str,
request_hash: &'life2 str,
owner_id: &'life3 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<bool>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Extend a pending claim only while it is still owned by owner_id.
Returns false after completion, takeover, release, or identity conflict.
fn complete<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
decision_id: &'life1 str,
request_hash: &'life2 str,
owner_id: &'life3 str,
completed_at_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn release<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
decision_id: &'life1 str,
request_hash: &'life2 str,
owner_id: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".