pub struct ModelInputSnapshotV1 {Show 24 fields
pub schema: String,
pub call_sequence: u64,
pub kind: ModelInputKindV1,
pub message_count: usize,
pub content_block_count: usize,
pub image_block_count: usize,
pub tool_result_count: usize,
pub tool_count: usize,
pub retrieval_result_count: usize,
pub retrieval_result_bytes: u64,
pub retrieval_results_digest: Option<String>,
pub system_bytes: u64,
pub message_payload_bytes: u64,
pub tool_definition_bytes: u64,
pub structured_output_bytes: u64,
pub payload_bytes: u64,
pub estimated_prompt_tokens: usize,
pub messages_digest: String,
pub system_digest: Option<String>,
pub tool_definitions_digest: String,
pub structured_output_digest: Option<String>,
pub input_digest: String,
pub capability_snapshot_digest: String,
pub snapshot_digest: String,
}Expand description
Immutable, bounded evidence for the arguments submitted to one provider-neutral model call.
Fields
schema: Stringcall_sequence: u64kind: ModelInputKindV1message_count: usizecontent_block_count: usizeimage_block_count: usizetool_result_count: usizetool_count: usizeretrieval_result_count: usizeretrieval_result_bytes: u64retrieval_results_digest: Option<String>system_bytes: u64message_payload_bytes: u64tool_definition_bytes: u64structured_output_bytes: u64payload_bytes: u64estimated_prompt_tokens: usizemessages_digest: Stringsystem_digest: Option<String>tool_definitions_digest: Stringstructured_output_digest: Option<String>input_digest: Stringcapability_snapshot_digest: Stringsnapshot_digest: StringImplementations
Sourceimpl ModelInputSnapshotV1
impl ModelInputSnapshotV1
pub fn validate(&self) -> Result<(), HarnessEvidenceError>
Sourcepub fn validate_against(
&self,
capability: &RunCapabilitySnapshotV1,
) -> Result<(), HarnessEvidenceError>
pub fn validate_against( &self, capability: &RunCapabilitySnapshotV1, ) -> Result<(), HarnessEvidenceError>
Validate this input and the exact capability snapshot it references.