pub struct RunCapabilitySnapshotV1 {
pub schema: String,
pub model_visible_tool_count: usize,
pub model_visible_tools_digest: String,
pub workspace: WorkspaceCapabilitySnapshotV1,
pub policy: RunPolicyCeilingSnapshotV1,
pub retrieval: WorkspaceRetrievalCapabilitySnapshotV1,
pub snapshot_digest: String,
}Expand description
Immutable description of the exact capability surface exposed for a model call. The digest excludes itself and remains stable while the surface and retrieval readiness generation remain unchanged.
Fields
schema: Stringmodel_visible_tool_count: usizemodel_visible_tools_digest: Stringworkspace: WorkspaceCapabilitySnapshotV1policy: RunPolicyCeilingSnapshotV1retrieval: WorkspaceRetrievalCapabilitySnapshotV1snapshot_digest: StringImplementations
Sourceimpl RunCapabilitySnapshotV1
impl RunCapabilitySnapshotV1
pub fn validate(&self) -> Result<(), HarnessEvidenceError>