pub struct RunPolicyCeilingSnapshotV1 {
pub permission_checker_bound: bool,
pub permission_policy_digest: Option<String>,
pub confirmation_manager_bound: bool,
pub confirmation_policy_digest: Option<String>,
pub budget_guard_bound: bool,
pub active_skill_tool_restrictions: bool,
pub max_tool_rounds: usize,
pub max_parallel_tasks: usize,
pub tool_timeout_ms: Option<u64>,
pub llm_api_timeout_ms: Option<u64>,
pub max_execution_time_ms: Option<u64>,
}Expand description
Run-owned governance bindings, serializable policy identities, and execution ceilings observed for the same run as the model call.
Fields
permission_checker_bound: boolpermission_policy_digest: Option<String>confirmation_manager_bound: boolconfirmation_policy_digest: Option<String>budget_guard_bound: boolactive_skill_tool_restrictions: boolmax_tool_rounds: usizemax_parallel_tasks: usizetool_timeout_ms: Option<u64>llm_api_timeout_ms: Option<u64>max_execution_time_ms: Option<u64>Trait Implementations
Sourceimpl Clone for RunPolicyCeilingSnapshotV1
impl Clone for RunPolicyCeilingSnapshotV1
Sourcefn clone(&self) -> RunPolicyCeilingSnapshotV1
fn clone(&self) -> RunPolicyCeilingSnapshotV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RunPolicyCeilingSnapshotV1
impl Debug for RunPolicyCeilingSnapshotV1
Sourceimpl<'de> Deserialize<'de> for RunPolicyCeilingSnapshotV1
impl<'de> Deserialize<'de> for RunPolicyCeilingSnapshotV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RunPolicyCeilingSnapshotV1
impl StructuralPartialEq for RunPolicyCeilingSnapshotV1