pub struct WorkspaceRetrievalCapabilitySnapshotV1 {
pub enabled: bool,
pub phase: WorkspaceRetrievalPhase,
pub catalog_revision: u64,
pub source_revision: u64,
pub vector_revision: u64,
pub coverage_bps: u16,
pub model_digest: Option<String>,
}Expand description
Exact semantic readiness and generation identities observed immediately before a model call. Model identity is represented only by a digest of the non-sensitive provider descriptor.
Fields
enabled: boolphase: WorkspaceRetrievalPhasecatalog_revision: u64source_revision: u64vector_revision: u64coverage_bps: u16model_digest: Option<String>Trait Implementations
Sourceimpl Clone for WorkspaceRetrievalCapabilitySnapshotV1
impl Clone for WorkspaceRetrievalCapabilitySnapshotV1
Sourcefn clone(&self) -> WorkspaceRetrievalCapabilitySnapshotV1
fn clone(&self) -> WorkspaceRetrievalCapabilitySnapshotV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for WorkspaceRetrievalCapabilitySnapshotV1
impl<'de> Deserialize<'de> for WorkspaceRetrievalCapabilitySnapshotV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkspaceRetrievalCapabilitySnapshotV1
impl StructuralPartialEq for WorkspaceRetrievalCapabilitySnapshotV1