Module program

Module program 

Programmatic tool calling primitives.

A program is a named, deterministic chain of tool invocations executed by the harness instead of expanded turn-by-turn through the model loop.

Structs

Program
ProgramCatalog
ProgramExecutor
ProgramParameter
ProgramResult
ProgramStep
ProgramStepResult
ProgramStepTemplate
ProgramTemplate
ProgramTemplateIssue
ProgramTemplateValidation
ProgramTrace
ProgramTraceArtifact
ProgramTraceStep
ProgramVerificationHint

Constants

PROGRAM_TRACE_SCHEMA

Functions

builtin_program_templates
program_code_search
program_repo_map
program_verification_hints