pub enum TaskHandlerMode {
Internal,
External,
Hybrid,
}Expand description
Task handler mode determines how tasks in a lane are processed
Variants
Internal
Tasks are executed internally within the runtime (default)
External
Tasks are sent to external handler (SDK), wait for callback
Hybrid
Tasks are executed internally but also notify external handler