agent_harness_compatibility_v1

Function agent_harness_compatibility_v1 

pub fn agent_harness_compatibility_v1() -> AgentReleaseCompatibility
Exact protocol and capability surface supplied by the native v1 Harness.

Keeping this in Core prevents executable hosts from independently copying capability names or levels when they admit an Agent release.