pub struct ResearchCitationV1 {
pub schema: String,
pub citation_id: String,
pub project_id: String,
pub run_id: String,
pub claim_id: String,
pub source_digest: String,
pub source_span_digest: String,
pub locator: Option<String>,
pub observed_at_ms: u64,
pub citation_digest: String,
}Expand description
One bounded citation from a claim to a source span or evidence fact.
Citations carry digests only. Hosts retain source text and locators behind those digests and optional bounded locator text for UI routing.
Fields
schema: Stringcitation_id: Stringproject_id: Stringrun_id: Stringclaim_id: Stringsource_digest: Stringsource_span_digest: Stringlocator: Option<String>observed_at_ms: u64citation_digest: StringImplementations
Sourceimpl ResearchCitationV1
impl ResearchCitationV1
pub fn new( citation_id: impl Into<String>, project_id: impl Into<String>, run_id: impl Into<String>, claim_id: impl Into<String>, source_digest: impl Into<String>, source_span_digest: impl Into<String>, locator: Option<String>, observed_at_ms: u64, ) -> Result<Self, ResearchContractError>
pub fn validate_for_run( &self, run: &ResearchRunV1, ) -> Result<(), ResearchContractError>
pub fn validate(&self) -> Result<(), ResearchContractError>
pub fn from_slice(bytes: &[u8]) -> Result<Self, ResearchContractError>
pub fn to_vec(&self) -> Result<Vec<u8>, ResearchContractError>