pub struct ResearchProvenanceReceiptV1 {Show 16 fields
pub schema: String,
pub project_id: String,
pub project_revision: u64,
pub run_id: String,
pub artifact_id: String,
pub artifact_kind: ResearchArtifactKindV1,
pub artifact_digest: String,
pub input_digests: Vec<String>,
pub workflow_digest: String,
pub code_digest: String,
pub environment_digest: String,
pub provider_id: String,
pub model_digest: Option<String>,
pub random_seed: Option<u64>,
pub validation_digest: Option<String>,
pub receipt_digest: String,
}Expand description
Reproducibility identity for one generated artifact.
Fields
schema: Stringproject_id: Stringproject_revision: u64run_id: Stringartifact_id: Stringartifact_kind: ResearchArtifactKindV1artifact_digest: Stringinput_digests: Vec<String>workflow_digest: Stringcode_digest: Stringenvironment_digest: Stringprovider_id: Stringmodel_digest: Option<String>random_seed: Option<u64>validation_digest: Option<String>receipt_digest: StringImplementations
Sourceimpl ResearchProvenanceReceiptV1
impl ResearchProvenanceReceiptV1
pub fn new( project_id: impl Into<String>, project_revision: u64, run_id: impl Into<String>, artifact_id: impl Into<String>, artifact_kind: ResearchArtifactKindV1, artifact_digest: impl Into<String>, input_digests: Vec<String>, workflow_digest: impl Into<String>, code_digest: impl Into<String>, environment_digest: impl Into<String>, provider_id: impl Into<String>, model_digest: Option<String>, random_seed: Option<u64>, validation_digest: Option<String>, ) -> Result<Self, ResearchContractError>
pub fn validate(&self) -> Result<(), ResearchContractError>
Sourcepub fn from_slice(bytes: &[u8]) -> Result<Self, ResearchContractError>
pub fn from_slice(bytes: &[u8]) -> Result<Self, ResearchContractError>
Decode a bounded JSON provenance receipt and validate its identity before returning it to a caller at a process boundary.