pub struct DefaultSecurityProvider { /* private fields */ }Expand description
Default security provider with taint tracking, sanitization, and injection detection
Implementations
Sourceimpl DefaultSecurityProvider
impl DefaultSecurityProvider
Sourcepub fn with_config(config: DefaultSecurityConfig) -> Self
pub fn with_config(config: DefaultSecurityConfig) -> Self
Create a new default security provider with custom config
Sourcepub fn detect_injection(&self, text: &str) -> Vec<String>
pub fn detect_injection(&self, text: &str) -> Vec<String>
Check for injection patterns