pub fn sanitize_tainted_json(
provider: &dyn SecurityProvider,
value: TaintedValue<Value>,
) -> TaintedValue<Value>Expand description
Process complete JSON string values while retaining keys and protocol shape. Keys are protocol field names, not a channel for arbitrary output text.