pub fn admit(
session_id: &str,
command: &str,
admission: CommandAdmission,
) -> Result<AdmittedCommand>Expand description
Apply a command to the session. A denial does not change cwd or start a job.
pub fn admit(
session_id: &str,
command: &str,
admission: CommandAdmission,
) -> Result<AdmittedCommand>Apply a command to the session. A denial does not change cwd or start a job.