pub fn parse_agent_md(content: &str) -> Result<AgentDefinition>Expand description
Parse an agent definition from Markdown with YAML frontmatter
The frontmatter contains agent metadata, and the body becomes the prompt.
pub fn parse_agent_md(content: &str) -> Result<AgentDefinition>Parse an agent definition from Markdown with YAML frontmatter
The frontmatter contains agent metadata, and the body becomes the prompt.