pub struct ToolResultTransformBindingV1 {
pub schema: String,
pub transform_algorithm: String,
pub policy_digest: String,
pub binding_digest: String,
}Expand description
Bounded evidence that binds one Tool result to its exact deterministic transform algorithm and policy without copying Cloud or provider identity into Core.
Fields
schema: Stringtransform_algorithm: Stringpolicy_digest: Stringbinding_digest: StringImplementations
Sourceimpl ToolResultTransformBindingV1
impl ToolResultTransformBindingV1
pub fn from_policy(policy: &ToolResultTransformPolicyV1) -> Result<Self>
pub fn validate(&self) -> Result<()>
pub fn validate_for_policy( &self, policy: &ToolResultTransformPolicyV1, ) -> Result<()>