pub trait UseRuntimeTaskDispatcher:
Send
+ Sync
+ 'static {
// Required method
fn invoke<'life0, 'async_trait>(
&'life0 self,
request: UseRuntimeTaskRequestV1,
) -> Pin<Box<dyn Future<Output = UseRuntimeTaskResult<UseRuntimeTaskExecutionV1>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Trusted host seam that adapts the request to A3S Use’s leased
RuntimeTaskDispatcher and returns only after Runtime cleanup has settled.
Required Methods
fn invoke<'life0, 'async_trait>(
&'life0 self,
request: UseRuntimeTaskRequestV1,
) -> Pin<Box<dyn Future<Output = UseRuntimeTaskResult<UseRuntimeTaskExecutionV1>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".