pub struct ChunkCatalogSnapshot { /* private fields */ }Expand description
Immutable, query-safe view of one catalog revision.
Implementations
Sourceimpl ChunkCatalogSnapshot
impl ChunkCatalogSnapshot
pub fn revision(&self) -> u64
pub fn source_revision(&self) -> u64
pub fn file_count(&self) -> usize
pub fn chunk_count(&self) -> usize
pub fn text_bytes(&self) -> usize
pub fn estimated_index_bytes(&self) -> usize
Sourcepub fn eligible_file_count(&self) -> usize
pub fn eligible_file_count(&self) -> usize
Number of files admitted by the workspace policy for this source revision, including files whose catalog build failed.
Sourcepub fn failed_file_count(&self) -> usize
pub fn failed_file_count(&self) -> usize
Number of admitted files that failed catalog construction for this source revision.
pub fn paths(&self) -> Vec<String>
pub fn content_digest(&self, path: &WorkspacePath) -> Option<Arc<str>>
pub fn chunks(&self) -> Arc<[Arc<WorkspaceChunk>]> ⓘ
pub fn lexical_search( &self, request: &LexicalSearchRequest, ) -> Result<LexicalSearchResult, WorkspaceIndexError>