pub struct WorkspaceHybridSearchHit {
pub chunk: Arc<WorkspaceChunk>,
pub fused_score: f64,
pub rerank_score: f64,
pub redundancy_score: f64,
pub exact_identifier: bool,
pub channels: Vec<WorkspaceHybridChannelRank>,
}Expand description
One current-source-verified fused match.
Fields
chunk: Arc<WorkspaceChunk>fused_score: f64rerank_score: f64Greedy selection score assigned by the applied rerank stage.
redundancy_score: f64Maximum interval or lexical similarity to an earlier selected hit.
exact_identifier: boolchannels: Vec<WorkspaceHybridChannelRank>Trait Implementations
Sourceimpl Clone for WorkspaceHybridSearchHit
impl Clone for WorkspaceHybridSearchHit
Sourcefn clone(&self) -> WorkspaceHybridSearchHit
fn clone(&self) -> WorkspaceHybridSearchHit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkspaceHybridSearchHit
impl Debug for WorkspaceHybridSearchHit
Sourceimpl PartialEq for WorkspaceHybridSearchHit
impl PartialEq for WorkspaceHybridSearchHit
impl StructuralPartialEq for WorkspaceHybridSearchHit