pub struct CapabilityScopeHandle<K: ScopeKind> { /* private fields */ }Expand description
Cloneable weak registration handle for one typed capability scope.
A handle can transfer tasks and reversible effects into an active scope, and the permitted marker-specific methods can derive child scopes. It does not retain the scope, its immutable catalog generation, or an upstream A3S Use lease. Once the owner closes or drops the scope, every operation fails closed.
Implementations
Sourceimpl CapabilityScopeHandle<Run>
impl CapabilityScopeHandle<Run>
pub fn turn( &self, local_id: impl Into<String>, ceiling: CapabilityCeiling, ) -> Result<CapabilityScope<Turn>, CapabilityScopeError>
pub fn turn_inheriting( &self, local_id: impl Into<String>, ) -> Result<CapabilityScope<Turn>, CapabilityScopeError>
pub fn subtask( &self, local_id: impl Into<String>, ceiling: CapabilityCeiling, ) -> Result<CapabilityScope<Subtask>, CapabilityScopeError>
pub fn subtask_inheriting( &self, local_id: impl Into<String>, ) -> Result<CapabilityScope<Subtask>, CapabilityScopeError>
Sourceimpl CapabilityScopeHandle<Turn>
impl CapabilityScopeHandle<Turn>
pub fn subtask( &self, local_id: impl Into<String>, ceiling: CapabilityCeiling, ) -> Result<CapabilityScope<Subtask>, CapabilityScopeError>
pub fn subtask_inheriting( &self, local_id: impl Into<String>, ) -> Result<CapabilityScope<Subtask>, CapabilityScopeError>
Sourceimpl CapabilityScopeHandle<Subtask>
impl CapabilityScopeHandle<Subtask>
pub fn turn( &self, local_id: impl Into<String>, ceiling: CapabilityCeiling, ) -> Result<CapabilityScope<Turn>, CapabilityScopeError>
pub fn turn_inheriting( &self, local_id: impl Into<String>, ) -> Result<CapabilityScope<Turn>, CapabilityScopeError>
pub fn subtask( &self, local_id: impl Into<String>, ceiling: CapabilityCeiling, ) -> Result<CapabilityScope<Subtask>, CapabilityScopeError>
pub fn subtask_inheriting( &self, local_id: impl Into<String>, ) -> Result<CapabilityScope<Subtask>, CapabilityScopeError>
Sourceimpl<K: ScopeKind> CapabilityScopeHandle<K>
impl<K: ScopeKind> CapabilityScopeHandle<K>
pub fn id(&self) -> &CapabilityScopeId
pub const fn kind(&self) -> CapabilityScopeKind
pub fn is_active(&self) -> bool
pub fn cancellation(&self) -> Result<CancellationToken, CapabilityScopeError>
pub fn register_effect<E>(&self, effect: E) -> Result<(), CapabilityScopeError>where
E: CapabilityEffect,
pub fn spawn_task<F>( &self, name: impl Into<String>, task: F, ) -> Result<SupervisedTaskId, CapabilityScopeError>
pub fn cancel(&self) -> Result<(), CapabilityScopeError>