Budgeted assembly for context items.
Structs
- Context
Assembler - Assembles raw provider results into a ranked, deduplicated, budgeted set.
- Context
Assembly - Final context selected for prompt rendering.
- Context
Assembly Policy - Named budget policy for context assembly.
- Context
Budget - Budget limits for prompt-bound context.
- Context
Source Policy - Source-aware limits that prevent one context source from dominating the prompt.