pub trait EvaluationDispatchLedger: Send + Sync {
// Required methods
fn claim<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
owner_id: &'life3 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<EvaluationDispatchClaimOutcome, EvaluationDispatchLedgerError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn renew<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
owner_id: &'life3 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<bool, EvaluationDispatchLedgerError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn complete<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
owner_id: &'life3 str,
completed_at_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<(), EvaluationDispatchLedgerError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn release<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
owner_id: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<(), EvaluationDispatchLedgerError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn prune_completed<'life0, 'async_trait>(
&'life0 self,
before_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<usize, EvaluationDispatchLedgerError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
// Provided methods
fn claim_with_identity<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<EvaluationDispatchClaimOutcome, EvaluationDispatchLedgerError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait { ... }
fn renew_with_identity<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<bool, EvaluationDispatchLedgerError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait { ... }
fn complete_with_receipt<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
receipt: &'life5 ExecutionResultReceiptV1,
completed_at_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<(), EvaluationDispatchLedgerError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait { ... }
fn release_with_identity<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
) -> Pin<Box<dyn Future<Output = Result<(), EvaluationDispatchLedgerError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait { ... }
fn completed_receipt<'life0, 'life1, 'async_trait>(
&'life0 self,
_dispatch_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Option<ExecutionResultReceiptV1>, EvaluationDispatchLedgerError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait { ... }
}Required Methods
fn claim<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
owner_id: &'life3 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<EvaluationDispatchClaimOutcome, EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn renew<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
owner_id: &'life3 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<bool, EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn complete<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
owner_id: &'life3 str,
completed_at_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<(), EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn release<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
owner_id: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<(), EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn prune_completed<'life0, 'async_trait>(
&'life0 self,
before_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<usize, EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Provided Methods
Sourcefn claim_with_identity<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<EvaluationDispatchClaimOutcome, EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
fn claim_with_identity<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<EvaluationDispatchClaimOutcome, EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
Claim a dispatch while binding its canonical execution identity. The default keeps third-party ledgers source-compatible; built-in ledgers persist and fence on the identity.
Sourcefn renew_with_identity<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<bool, EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
fn renew_with_identity<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
now_ms: u64,
lease_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<bool, EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
Renew a claim only when both its legacy ledger key and canonical identity still match the admitted worker.
Sourcefn complete_with_receipt<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
receipt: &'life5 ExecutionResultReceiptV1,
completed_at_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<(), EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
fn complete_with_receipt<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
receipt: &'life5 ExecutionResultReceiptV1,
completed_at_ms: u64,
) -> Pin<Box<dyn Future<Output = Result<(), EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
Complete a claim with a bounded digest-only result receipt.
Sourcefn release_with_identity<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
) -> Pin<Box<dyn Future<Output = Result<(), EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
fn release_with_identity<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
dispatch_id: &'life1 str,
request_digest: &'life2 str,
identity: &'life3 ExecutionIdentityV1,
owner_id: &'life4 str,
) -> Pin<Box<dyn Future<Output = Result<(), EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
Release a claim only when its canonical identity also matches. Legacy implementations fall back to the existing request/owner fence.
Sourcefn completed_receipt<'life0, 'life1, 'async_trait>(
&'life0 self,
_dispatch_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Option<ExecutionResultReceiptV1>, EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn completed_receipt<'life0, 'life1, 'async_trait>(
&'life0 self,
_dispatch_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Option<ExecutionResultReceiptV1>, EvaluationDispatchLedgerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Read the terminal receipt when the ledger supports result persistence.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".