FlowDecisionSink

Trait FlowDecisionSink 

pub trait FlowDecisionSink: Send + Sync {
    // Required method
    fn submit<'life0, 'life1, 'async_trait>(
        &'life0 self,
        request: &'life1 FlowDecisionRequest,
    ) -> Pin<Box<dyn Future<Output = Result<(), Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}

Required Methods

fn submit<'life0, 'life1, 'async_trait>( &'life0 self, request: &'life1 FlowDecisionRequest, ) -> Pin<Box<dyn Future<Output = Result<(), Box<dyn Error + Send + Sync>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Submit using request.decision_id as the downstream idempotency key. Implementations must deduplicate that key because an expired lease can be reclaimed after a process crashes between submission and receipt.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors