Git tool — Uses system git with auto-installation support
Provides Git operations using the external git command. If git is not installed, downloads and installs it automatically on Windows, macOS, and Linux.
Structs
- Branch
Info - Branch information.
- Commit
Info - Commit information for log display.
- Repo
Status - Repository status information.
- Stash
Info - Stash information.
- Worktree
Info - Worktree information.
Functions
- create_
branch - Create a new branch.
- create_
worktree - Create a new worktree.
- delete_
branch - Delete a branch.
- ensure_
git_ installed - Ensure git is installed. Downloads and installs git if not found.
- get_
diff - Get diff output.
- get_
git_ dir - Get the git directory path.
- get_log
- Get commit log.
- get_
status - Get repository status.
- is_
git_ available - Check if git is available on the system.
- is_
git_ repo - Check if a path is inside a git repository.
- list_
branches - List all local branches.
- list_
stashes - List stashes.
- list_
worktrees - List all worktrees.
- remove_
worktree - Remove a worktree.
- stash
- Create a stash.