Extensible Tool System
Provides a trait-based abstraction for tools.
Architecture
ToolRegistry
└── builtin tools (file, search, execution, web, and Code Intelligence queries)Re-exports
pub use crate::dynamic_workflow::register_dynamic_workflow;pub use task::parallel_task_params_schema;pub use task::task_params_schema;pub use task::ParallelTaskParams;pub use task::ParallelTaskTool;pub use task::TaskExecutor;pub use task::TaskParams;pub use task::TaskResult;pub use task::TaskTool;
Modules
- skill
- Skill Tool - Invoke skills as callable tools with temporary permission grants
- task
- Task tools for delegated child runs.
Structs
- Agent
DirScript Tool - A named, pre-parameterized
programscript call. - Artifact
Store - Artifact
Store Limits - Immutable
Content Adapter Binding V1 - Secret-free identity of the host authority bound to one Code session.
- Immutable
Content Adapter Session - Runtime pairing of a durable authority binding with one host adapter.
- Immutable
Content Descriptor V1 - Content identity computed by Code before a provider is called.
- Immutable
Content Reference V1 - Provider-neutral immutable reference returned by the authorized adapter.
- Immutable
Content Write Request V1 - Borrowed provider request. Its
Debugrepresentation excludes content. - Invocation
Runtime - Governed capabilities available to a tool during an agent/session invocation.
- Program
Tool - Tool
Artifact - Tool
Capabilities - Execution properties used by orchestrators to make safe scheduling choices.
- Tool
Context - Tool execution context
- Tool
Executor - Tool executor with workspace sandboxing
- Tool
Output - Tool execution output
- Tool
Presentation Profile V1 - Versioned, serializable Tool-presentation policy frozen by a Session and copied into each admitted Run.
- Tool
Registry - Tool registry for managing all available tools
- Tool
Result - Tool execution result returned by direct tool execution.
- Tool
Result Evidence V1 - Tool
Result Transform Binding V1 - Bounded evidence that binds one Tool result to its exact deterministic transform algorithm and policy without copying Cloud or provider identity into Core.
- Tool
Result Transform Policy V1
Enums
- Immutable
Content Error - Validation and provider failures at the immutable-content boundary.
- Immutable
Content Kind V1 - Closed purpose for one retained original-content object.
- Tool
Error Kind - Structured discriminant for tool failures.
- Tool
Output Kind - Primary representation produced by a tool invocation.
- Tool
Presentation Error - Tool
Presentation Mode V1 - Closed presentation modes supported by the version-1 profile contract.
- Tool
Result Loss Mode V1 - Tool
Stream Event - Events emitted by tools during execution
Constants
- IMMUTABLE_
CONTENT_ ADAPTER_ BINDING_ SCHEMA_ V1 - IMMUTABLE_
CONTENT_ DESCRIPTOR_ SCHEMA_ V1 - IMMUTABLE_
CONTENT_ REFERENCE_ SCHEMA_ V1 - MAX_
LINE_ LENGTH - Maximum line length before truncation
- MAX_
OUTPUT_ SIZE - Maximum output size in bytes before truncation
- MAX_
PROGRAM_ SCRIPT_ SOURCE_ BYTES - MAX_
READ_ LINES - Maximum lines to read from a file
- TOOL_
PRESENTATION_ PROFILE_ V1_ SCHEMA - TOOL_
RESULT_ CONTENT_ MEDIA_ TYPE - TOOL_
RESULT_ EVIDENCE_ SCHEMA_ V1 - TOOL_
RESULT_ TOKEN_ ESTIMATOR_ V1 - TOOL_
RESULT_ TRANSFORM_ ALGORITHM_ V1 - TOOL_
RESULT_ TRANSFORM_ BINDING_ METADATA_ KEY - TOOL_
RESULT_ TRANSFORM_ BINDING_ SCHEMA_ V1 - TOOL_
RESULT_ TRANSFORM_ POLICY_ DIGEST_ DOMAIN_ V1 - TOOL_
RESULT_ TRANSFORM_ SCHEMA_ V1
Traits
- Immutable
Content Adapter - Host port for create-only, exact-replay immutable content retention.
- Tool
- Tool trait - the core abstraction for all tools
Functions
- register_
generate_ object - Register the
generate_objecttool for structured JSON output. - register_
program - Register the programmatic tool calling wrapper.
- register_
program_ with_ catalog - Register the programmatic tool calling wrapper with a custom catalog.
- register_
task - Register the canonical
tasktool and hiddenparallel_taskcompatibility alias. - register_
task_ with_ mcp - Register the task delegation tools with optional MCP manager and parent context.
- register_
task_ with_ mcp_ managers - Register task delegation tools with ordered MCP capability sources.
- select_
tools_ for_ messages - Select the tools that should be exposed to the model for this turn.
- select_
tools_ for_ prompt
Type Aliases
- Immutable
Content Result - Tool
Event Sender - Sender for streaming tool output deltas during execution.