ImmutableContentAdapter

Trait ImmutableContentAdapter 

pub trait ImmutableContentAdapter: Send + Sync {
    // Required methods
    fn name(&self) -> &str;
    fn put<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        request: &'life1 ImmutableContentWriteRequestV1<'life2>,
    ) -> Pin<Box<dyn Future<Output = ImmutableContentResult<ImmutableContentReferenceV1>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait;
}
Host port for create-only, exact-replay immutable content retention.

The host must scope this object to an authorization already resolved outside Code. Repeating an identical descriptor must either return the byte-equivalent reference or fail; it must never overwrite another object.

Required Methods

fn name(&self) -> &str

fn put<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, request: &'life1 ImmutableContentWriteRequestV1<'life2>, ) -> Pin<Box<dyn Future<Output = ImmutableContentResult<ImmutableContentReferenceV1>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors